@@ -7,7 +7,7 @@ use utf8;
 
 use parent qw(Tickit::ContainerWidget);
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ Tickit::Widget::Layout::Desktop - provides a holder for "desktop-like" widget be
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -62,8 +62,7 @@ Constructed of:
 
 =item * L<Tickit::Widget::Layout::Desktop::Window> - the window implementation
 
-=item * this class - background desktop on which the
-floats are displayed
+=item * this class - background desktop on which the floats are displayed
 
 =back
 
@@ -110,7 +109,6 @@ floating windows on top of this widget.
 sub render_to_rb {
 	my ($self, $rb, $rect) = @_;
 	$rb->eraserect($rect);
-	# Tickit::RenderBuffer
 }
 
 sub children { @{shift->{widgets}} }
@@ -230,6 +228,7 @@ sub create_panel {
 		$args{lines},
 		$args{cols},
 	);
+	$float->cursor_at(0,0);
 
 	my $w = ($args{subclass} || 'Tickit::Widget::Layout::Desktop::Window')->new(
 		container => $self,
@@ -240,7 +239,7 @@ sub create_panel {
 
 	# Need to redraw our window if position or size change
 	$self->{extents}{refaddr $float} = $float->rect->translate(0,0);
-	$float->set_on_geom_changed($self->curry::weak::float_geom_changed($w));
+	$float->bind_event(geomchange => $self->curry::weak::float_geom_changed($w));
 	$w
 }
 
@@ -572,8 +571,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2016. Licensed under the same terms as Perl itself.
